==> calligra_2.8.1-1.orig.tar.xz: calligra-2.8.1/krita/plugins/extensions/clonesarray/dlg_clonesarray.h <==
/*
 *  Copyright (c) 2013 Dmitry Kazakov <dimula73@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef DLG_CLONESARRAY
#define DLG_CLONESARRAY

#include <kdialog.h>
#include <kis_global.h>

#include "kis_types.h"
#include "ui_wdg_clonesarray.h"

class KisView2;
class KisProcessingApplicator;


class WdgClonesArray : public QWidget, public Ui::WdgClonesArray
{
    Q_OBJECT

public:
    WdgClonesArray(QWidget *parent) : QWidget(parent) {
        setupUi(this);
    }
};

class DlgClonesArray: public KDialog
{

    Q_OBJECT

public:
    DlgClonesArray(KisView2 *view, QWidget * parent = 0);
    ~DlgClonesArray();

private slots:
    void okClicked();
    void applyClicked();
    void cancelClicked();

    void syncOrthogonalToAngular();
    void syncAngularToOrthogonal();

    void setDirty();
    void updateCheckboxAvailability();

private:
    void setOrthogonalSignalsEnabled(bool value);
    void setAngularSignalsEnabled(bool value);

    void initializeValues();
    void reapplyClones();

    void setClean();

private:
    WdgClonesArray *m_page;
    KisView2 *m_view;
    KisProcessingApplicator *m_applicator;
    KisLayerSP m_baseLayer;
    bool m_isDirty;
};

#endif // DLG_CLONESARRAY

==> calligra-2.9.0.tar.xz: calligra-2.9.0/krita/plugins/extensions/clonesarray/dlg_clonesarray.h <==
/*
 *  Copyright (c) 2013 Dmitry Kazakov <dimula73@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef DLG_CLONESARRAY
#define DLG_CLONESARRAY

#include <kdialog.h>
#include <kis_global.h>

#include "kis_types.h"
#include "ui_wdg_clonesarray.h"

class KisViewManager;
class KisProcessingApplicator;


class WdgClonesArray : public QWidget, public Ui::WdgClonesArray
{
    Q_OBJECT

public:
    WdgClonesArray(QWidget *parent) : QWidget(parent) {
        setupUi(this);
    }
};

class DlgClonesArray: public KDialog
{

    Q_OBJECT

public:
    DlgClonesArray(KisViewManager *view, QWidget * parent = 0);
    ~DlgClonesArray();

private slots:
    void okClicked();
    void applyClicked();
    void cancelClicked();

    void syncOrthogonalToAngular();
    void syncAngularToOrthogonal();

    void setDirty();
    void updateCheckboxAvailability();

private:
    void setOrthogonalSignalsEnabled(bool value);
    void setAngularSignalsEnabled(bool value);

    void initializeValues();
    void reapplyClones();

    void setClean();

private:
    WdgClonesArray *m_page;
    KisViewManager *m_view;
    KisProcessingApplicator *m_applicator;
    KisLayerSP m_baseLayer;
    bool m_isDirty;
};

#endif // DLG_CLONESARRAY
